@@ -3,12 +3,12 @@ from django.contrib.auth.models import User
 
 from celery.decorators import task
 
-from hoarder.backends import get_backends
+from hoarder.backends import get_async_backends
     
 
 @task
 def create_visitor(visitor_id):
-    for backend in get_backends():
+    for backend in get_async_backends():
         backend.create_visitor(visitor_id)
 
 
@@ -17,7 +17,7 @@ def register_event(event_type,
                    visitor_id,
                    when,
                    data):    
-    for backend in get_backends():
+    for backend in get_async_backends():
         backend.register_event(event_type,
                                visitor_id,
                                when,
@@ -27,14 +27,14 @@ def register_event(event_type,
 @task
 def label_visitor(visitor_id,
                   label):    
-    for backend in get_backends():
+    for backend in get_async_backends():
         backend.label_visitor(visitor_id,
                               label)
 
 
 @task
 def deduplicate(from_visitor_id, to_visitor_id):
-    for backend in get_backends():
+    for backend in get_async_backends():
         backend.deduplicate(from_visitor_id,
                             to_visitor_id)
 
@@ -44,7 +44,7 @@ def deduplicate(from_visitor_id, to_visitor_id):
 @task
 def set_user(visitor_id, user_id):
     user = User.objects.get(id=user_id)
-    for backend in get_backends():
+    for backend in get_async_backends():
         backend.set_user(visitor_id,
                          user)
     
